Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2019-07-21 21:52:20 +0300
committerDavid Crocker <dcrocker@eschertech.com>2019-07-21 21:52:20 +0300
commit62d5270b85d83836b705597690e4a110a66ba9f0 (patch)
tree36ada13d836019797742405c3bab7db040ae8a20 /src/Endstops/ZProbe.h
parent625bdb8073f1c6a230fe1b73e896025d1191767f (diff)
Sensors are configurted separately from heaters
Sensors are now configured separately from heaters. The M305 command is withdrawn and replaced by M308. M950 is extended to sspecify the sensor number when defining a heater.
Diffstat (limited to 'src/Endstops/ZProbe.h')
-rw-r--r--src/Endstops/ZProbe.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/Endstops/ZProbe.h b/src/Endstops/ZProbe.h
index 2ba00f15..2178cbc0 100644
--- a/src/Endstops/ZProbe.h
+++ b/src/Endstops/ZProbe.h
@@ -80,7 +80,7 @@ private:
turnHeatersOff : 1, // true to turn heaters off while probing
saveToConfigOverride : 1; // true if the trigger height should be saved to config-override.g
ZProbeType type;
- int8_t heater; // the heater number used for temperature calibration
+ int sensor; // the sensor number used for temperature calibration
};
// If this is a dumb modulated IR probe, set the IR LED on or off. Called from the tick ISR, so inlined for speed.